@@ -5,17 +5,20 @@ from importlib import resources  # Python 3.7+
 import sys
 
 from gitvars import readvars
+from gitvars import printvars
 
 def main():
     """Import the gitlab variables"""
     # Import Gitlab CI/CD variables from your project
     cfg = ConfigParser()
     cfg.read_string(resources.read_text("gitvars", "config.txt"))
-    gitlabapi_baseurl = cfg.get("project", "gitlabapi_baseurl")
+    gitlab_project = cfg.get("project", "gitlab_project")
+    var_prefix = cfg.get("project", "var_prefix")
 
     # If an article ID is given, show the article
     if len(sys.argv) > 1:
-        cicd_vars = readvars._read(gitlabapi_baseurl, sys.argv[1])
+        cicd_vars = readvars._read(sys.argv[1], gitlab_project, var_prefix)
+        printvars._prettyprint(cicd_vars)
 
     # If no ID is given, show a list of all articles
     else:
